@@ -6,7 +6,7 @@ from requests import get
 import utils
 
 
-def author(author_id, output_format='dict', pretty_print=None):
+def author(author_id, output_format='dictionary', pretty_print=None):
     url = f'http://sinta.ristekbrin.go.id/authors/detail?id={author_id}&view=overview'
     html = get(url)
     soup = BeautifulSoup(html.content, 'html.parser')
@@ -32,7 +32,7 @@ def author(author_id, output_format='dict', pretty_print=None):
 
     affiliation = soup.select('.au-affil > a')
     affiliation_name = affiliation[0].text
-    affiliation_url = 'http://sinta.ristekbrin.go.id/' + affiliation[0]['href']
+    affiliation_url = 'http://sinta.ristekbrin.go.id' + affiliation[0]['href']
     affiliation_id = re.search(r'id=(\d+)', affiliation_url).group(1)
 
     result = {
@@ -56,7 +56,7 @@ def author(author_id, output_format='dict', pretty_print=None):
     return utils.format_output(result, output_format=output_format, pretty_print=pretty_print)
 
 
-def dept_authors(affil_id, dept_id, output_format='dict', pretty_print=None):
+def dept_authors(affil_id, dept_id, output_format='dictionary', pretty_print=None):
     url = f'http://sinta.ristekbrin.go.id/departments/detail?afil={affil_id}&id={dept_id}&view=authors'
     html = get(url)
     soup = BeautifulSoup(html.content, 'html.parser')
